@@ -4,13 +4,14 @@ import Pyro4
 
 print("Autoreconnect using PYRO uri.")
 
+
+@Pyro4.expose
 class TestClass(object):
-    def method(self,arg):
+    def method(self, arg):
         print("Method called with %s" % arg)
         print("You can now try to stop this server with ctrl-C/ctrl-Break")
         time.sleep(1)
 
-obj=TestClass()
 
 # We are responsible to (re)connect objects with the same object Id,
 # so that the client can reuse its PYRO-uri directly to reconnect.
@@ -21,8 +22,7 @@ obj=TestClass()
 # The other thing is that your Daemon must re-bind on the same port.
 # By default Pyro will select a random port so we specify a fixed port.
 
-daemon = Pyro4.core.Daemon(port=7777)
-uri = daemon.register(obj,objectId="example.autoreconnect_fixed_objectid")
-
-print("Server started, uri=%s" % uri)
-daemon.requestLoop()
+with Pyro4.core.Daemon(port=7777) as daemon:
+    uri = daemon.register(TestClass, objectId="example.autoreconnect_fixed_objectid")
+    print("Server started, uri: %s" % uri)
+    daemon.requestLoop()
