@@ -1,5 +1,5 @@
 from __future__ import print_function
-import Pyro4
+import Pyro4.core
 
 obj = Pyro4.core.Proxy("PYRONAME:example.chain.A")
 print("Result=%s" % obj.process(["hello"]))
