@@ -7,6 +7,7 @@ try:
 except ImportError:
     from itertools import zip_longest
 import Pyro4
+import Pyro4.errors
 
 
 @Pyro4.expose
@@ -40,13 +41,19 @@ def grouper(n, iterable, padvalue=None):
 class Dispatcher(object):
     def count(self, lines):
         # use the name server's prefix lookup to get all registered wordcounters
-        all_counters = Pyro4.locateNS().list(prefix="example.dc.wordcount.")
-        counters = [Pyro4.async(Pyro4.Proxy(uri)) for uri in all_counters.values()]
+        with Pyro4.locateNS() as ns:
+            all_counters = ns.list(prefix="example.dc.wordcount.")
+        counters = [Pyro4.Proxy(uri) for uri in all_counters.values()]
+        for c in counters:
+            c._pyroAsync()   # set proxy in async mode
         roundrobin_counters = cycle(counters)
 
         # chop the text into chunks that can be distributed across the workers
         # uses async proxy so that we can hand off everything in parallel
         # counter is selected in a round-robin fashion from list of all available counters
+        # (This is a brain dead way because it doesn't scale - all the async calls are hogging
+        # the worker threads in the server. That's why we've increased that a lot at the start
+        # of this file, just for the sake of this example!)
         async_results = []
         for chunk in grouper(100, lines):
             counter = next(roundrobin_counters)
@@ -57,7 +64,12 @@ class Dispatcher(object):
         print("Collecting %d results..." % len(async_results))
         totals = Counter()
         for result in async_results:
-            totals.update(result.value)
+            try:
+                totals.update(result.value)
+            except Pyro4.errors.CommunicationError as x:
+                raise Pyro4.errors.PyroError("Something went wrong in the server when collecting the async responses: "+str(x))
+        for proxy in counters:
+            proxy._pyroRelease()
         return totals
 
 
